@@ -1,21 +1,21 @@
-/* vi:set sw=2 sts=2 ts=2 et ai: */
+/* vi:set expandtab sw=2 sts=2: */
 /*-
- * Copyright (c) 2008 Jannis Pohlmann <jannis@xfce.org>.
+ * Copyright (c) 2008 Jannis Pohlmann <jannis@xfce.org>
  *
- * This program is free software; you can redistribute it and/or modify 
- * it under the terms of the GNU General Public License as published by 
- * the Free Software Foundation; either version 2 of the License, or (at 
- * your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License 
- * along with this program; if not, write to the Free Software 
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
- * MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __XFCE_MIXER_CARD_COMBO_H__
@@ -23,7 +23,7 @@
 
 #include <gtk/gtk.h>
 
-G_BEGIN_DECLS;
+G_BEGIN_DECLS
 
 typedef struct _XfceMixerCardComboClass XfceMixerCardComboClass;
 typedef struct _XfceMixerCardCombo      XfceMixerCardCombo;
@@ -39,7 +39,9 @@ GType       xfce_mixer_card_combo_get_type        (void) G_GNUC_CONST;
 
 GtkWidget  *xfce_mixer_card_combo_new             (GstElement         *element);
 GstElement *xfce_mixer_card_combo_get_active_card (XfceMixerCardCombo *combo);
+void        xfce_mixer_card_combo_set_active_card (XfceMixerCardCombo *combo,
+                                                   GstElement         *card);
 
-G_END_DECLS;
+G_END_DECLS
 
 #endif /* !__XFCE_MIXER_CARD_COMBO_H__ */
