@@ -1,22 +1,21 @@
-/* $Id: xfce-mixer-track.h 28051 2008-10-06 13:39:46Z jannis $ */
-/* vim:set sw=2 sts=2 ts=2 et ai: */
+/* vi:set expandtab sw=2 sts=2: */
 /*-
  * Copyright (c) 2008 Jannis Pohlmann <jannis@xfce.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __XFCE_MIXER_TRACK_H__
@@ -25,7 +24,7 @@
 #include <gtk/gtk.h>
 #include <gst/gst.h>
 
-G_BEGIN_DECLS;
+G_BEGIN_DECLS
 
 typedef struct _XfceMixerTrackClass XfceMixerTrackClass;
 typedef struct _XfceMixerTrack      XfceMixerTrack;
@@ -45,6 +44,6 @@ void       xfce_mixer_track_update_mute   (XfceMixerTrack *track);
 void       xfce_mixer_track_update_record (XfceMixerTrack *track);
 void       xfce_mixer_track_update_volume (XfceMixerTrack *track);
 
-G_END_DECLS;
+G_END_DECLS
 
 #endif /* !__XFCE_MIXER_TRACK_H__ */
